#ifndef _MAPSERVER_VERSION_H
#define _MAPSERVER_VERSION_H

#define MS_VERSION_MAJOR 8
#define MS_VERSION_MINOR 4
#define MS_VERSION_REV 1
#define MS_VERSION "8.4.1"
#define MS_VERSION_NUM  80401 

#endif

